instrumenttools.AltoSaxophone
=============================

.. inheritance-diagram:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone
   :private-bases:

.. autoclass:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.default_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.default_short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.effective_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.format

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.interval_of_transposition

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.is_primary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.is_secondary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.is_transposing

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.target_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.traditional_pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.all_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.primary_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.short_instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.sounding_pitch_of_fingered_middle_c

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Methods
-------

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.attach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.detach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.get_default_performer_name

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.get_performer_names

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__eq__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__hash__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.instrumenttools.AltoSaxophone.AltoSaxophone.AltoSaxophone.__str__

    Inherited from `__builtin__.object`
